# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/customer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import customer_pay_per_conversion_eligibility_failure_reason_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__pay__per__conversion__eligibility__failure__reason__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/customer.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\rCustomerProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n6google/ads/googleads_v2/proto/resources/customer.proto\x12!google.ads.googleads.v2.resources\x1a`google/ads/googleads_v2/proto/enums/customer_pay_per_conversion_eligibility_failure_reason.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xfe\x07\n\x08\x43ustomer\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10\x64\x65scriptive_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rcurrency_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x66inal_url_suffix\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x14\x61uto_tagging_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12has_partners_badge\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07manager\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0ctest_account\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12W\n\x16\x63\x61ll_reporting_setting\x18\n \x01(\x0b\x32\x37.google.ads.googleads.v2.resources.CallReportingSetting\x12\x61\n\x1b\x63onversion_tracking_setting\x18\x0e \x01(\x0b\x32<.google.ads.googleads.v2.resources.ConversionTrackingSetting\x12R\n\x13remarketing_setting\x18\x0f \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.RemarketingSetting\x12\xbd\x01\n.pay_per_conversion_eligibility_failure_reasons\x18\x10 \x03(\x0e\x32\x84\x01.google.ads.googleads.v2.enums.CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason\"\xd7\x01\n\x14\x43\x61llReportingSetting\x12:\n\x16\x63\x61ll_reporting_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n!call_conversion_reporting_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16\x63\x61ll_conversion_action\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa3\x01\n\x19\x43onversionTrackingSetting\x12;\n\x16\x63onversion_tracking_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n$cross_account_conversion_tracking_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"R\n\x12RemarketingSetting\x12<\n\x16google_global_site_tag\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfa\x01\n%com.google.ads.googleads.v2.resourcesB\rCustomerProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__pay__per__conversion__eligibility__failure__reason__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CUSTOMER = _descriptor.Descriptor(
  name='Customer',
  full_name='google.ads.googleads.v2.resources.Customer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.Customer.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.Customer.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptive_name', full_name='google.ads.googleads.v2.resources.Customer.descriptive_name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.resources.Customer.currency_code', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='google.ads.googleads.v2.resources.Customer.time_zone', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.resources.Customer.tracking_url_template', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.resources.Customer.final_url_suffix', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_tagging_enabled', full_name='google.ads.googleads.v2.resources.Customer.auto_tagging_enabled', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_partners_badge', full_name='google.ads.googleads.v2.resources.Customer.has_partners_badge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manager', full_name='google.ads.googleads.v2.resources.Customer.manager', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_account', full_name='google.ads.googleads.v2.resources.Customer.test_account', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_reporting_setting', full_name='google.ads.googleads.v2.resources.Customer.call_reporting_setting', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_tracking_setting', full_name='google.ads.googleads.v2.resources.Customer.conversion_tracking_setting', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_setting', full_name='google.ads.googleads.v2.resources.Customer.remarketing_setting', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pay_per_conversion_eligibility_failure_reasons', full_name='google.ads.googleads.v2.resources.Customer.pay_per_conversion_eligibility_failure_reasons', index=14,
      number=16, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=1276,
)


_CALLREPORTINGSETTING = _descriptor.Descriptor(
  name='CallReportingSetting',
  full_name='google.ads.googleads.v2.resources.CallReportingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_reporting_enabled', full_name='google.ads.googleads.v2.resources.CallReportingSetting.call_reporting_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_reporting_enabled', full_name='google.ads.googleads.v2.resources.CallReportingSetting.call_conversion_reporting_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_action', full_name='google.ads.googleads.v2.resources.CallReportingSetting.call_conversion_action', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1494,
)


_CONVERSIONTRACKINGSETTING = _descriptor.Descriptor(
  name='ConversionTrackingSetting',
  full_name='google.ads.googleads.v2.resources.ConversionTrackingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_tracking_id', full_name='google.ads.googleads.v2.resources.ConversionTrackingSetting.conversion_tracking_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cross_account_conversion_tracking_id', full_name='google.ads.googleads.v2.resources.ConversionTrackingSetting.cross_account_conversion_tracking_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1660,
)


_REMARKETINGSETTING = _descriptor.Descriptor(
  name='RemarketingSetting',
  full_name='google.ads.googleads.v2.resources.RemarketingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='google_global_site_tag', full_name='google.ads.googleads.v2.resources.RemarketingSetting.google_global_site_tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1744,
)

_CUSTOMER.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CUSTOMER.fields_by_name['descriptive_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['auto_tagging_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['has_partners_badge'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['manager'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['test_account'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['call_reporting_setting'].message_type = _CALLREPORTINGSETTING
_CUSTOMER.fields_by_name['conversion_tracking_setting'].message_type = _CONVERSIONTRACKINGSETTING
_CUSTOMER.fields_by_name['remarketing_setting'].message_type = _REMARKETINGSETTING
_CUSTOMER.fields_by_name['pay_per_conversion_eligibility_failure_reasons'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__pay__per__conversion__eligibility__failure__reason__pb2._CUSTOMERPAYPERCONVERSIONELIGIBILITYFAILUREREASONENUM_CUSTOMERPAYPERCONVERSIONELIGIBILITYFAILUREREASON
_CALLREPORTINGSETTING.fields_by_name['call_reporting_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLREPORTINGSETTING.fields_by_name['call_conversion_reporting_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLREPORTINGSETTING.fields_by_name['call_conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONTRACKINGSETTING.fields_by_name['conversion_tracking_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONVERSIONTRACKINGSETTING.fields_by_name['cross_account_conversion_tracking_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REMARKETINGSETTING.fields_by_name['google_global_site_tag'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Customer'] = _CUSTOMER
DESCRIPTOR.message_types_by_name['CallReportingSetting'] = _CALLREPORTINGSETTING
DESCRIPTOR.message_types_by_name['ConversionTrackingSetting'] = _CONVERSIONTRACKINGSETTING
DESCRIPTOR.message_types_by_name['RemarketingSetting'] = _REMARKETINGSETTING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Customer = _reflection.GeneratedProtocolMessageType('Customer', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMER,
  __module__ = 'google.ads.googleads_v2.proto.resources.customer_pb2'
  ,
  __doc__ = """A customer.
  
  
  Attributes:
      resource_name:
          The resource name of the customer. Customer resource names
          have the form:  ``customers/{customer_id}``
      id:
          The ID of the customer.
      descriptive_name:
          Optional, non-unique descriptive name of the customer.
      currency_code:
          The currency in which the account operates. A subset of the
          currency codes from the ISO 4217 standard is supported.
      time_zone:
          The local timezone ID of the customer.
      tracking_url_template:
          The URL template for constructing a tracking URL out of
          parameters.
      final_url_suffix:
          The URL template for appending params to the final URL
      auto_tagging_enabled:
          Whether auto-tagging is enabled for the customer.
      has_partners_badge:
          Whether the Customer has a Partners program badge. If the
          Customer is not associated with the Partners program, this
          will be false. For more information, see
          https://support.google.com/partners/answer/3125774.
      manager:
          Whether the customer is a manager.
      test_account:
          Whether the customer is a test account.
      call_reporting_setting:
          Call reporting setting for a customer.
      conversion_tracking_setting:
          Conversion tracking setting for a customer.
      remarketing_setting:
          Remarketing setting for a customer.
      pay_per_conversion_eligibility_failure_reasons:
          Reasons why the customer is not eligible to use
          PaymentMode.CONVERSIONS. If the list is empty, the customer is
          eligible. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Customer)
  ))
_sym_db.RegisterMessage(Customer)

CallReportingSetting = _reflection.GeneratedProtocolMessageType('CallReportingSetting', (_message.Message,), dict(
  DESCRIPTOR = _CALLREPORTINGSETTING,
  __module__ = 'google.ads.googleads_v2.proto.resources.customer_pb2'
  ,
  __doc__ = """Call reporting setting for a customer.
  
  
  Attributes:
      call_reporting_enabled:
          Enable reporting of phone call events by redirecting them via
          Google System.
      call_conversion_reporting_enabled:
          Whether to enable call conversion reporting.
      call_conversion_action:
          Customer-level call conversion action to attribute a call
          conversion to. If not set a default conversion action is used.
          Only in effect when call\_conversion\_reporting\_enabled is
          set to true.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.CallReportingSetting)
  ))
_sym_db.RegisterMessage(CallReportingSetting)

ConversionTrackingSetting = _reflection.GeneratedProtocolMessageType('ConversionTrackingSetting', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONTRACKINGSETTING,
  __module__ = 'google.ads.googleads_v2.proto.resources.customer_pb2'
  ,
  __doc__ = """A collection of customer-wide settings related to Google Ads Conversion
  Tracking.
  
  
  Attributes:
      conversion_tracking_id:
          The conversion tracking id used for this account. This id is
          automatically assigned after any conversion tracking feature
          is used. If the customer doesn't use conversion tracking, this
          is 0. This field is read-only.
      cross_account_conversion_tracking_id:
          The conversion tracking id of the customer's manager. This is
          set when the customer is opted into cross account conversion
          tracking, and it overrides conversion\_tracking\_id. This
          field can only be managed through the Google Ads UI. This
          field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.ConversionTrackingSetting)
  ))
_sym_db.RegisterMessage(ConversionTrackingSetting)

RemarketingSetting = _reflection.GeneratedProtocolMessageType('RemarketingSetting', (_message.Message,), dict(
  DESCRIPTOR = _REMARKETINGSETTING,
  __module__ = 'google.ads.googleads_v2.proto.resources.customer_pb2'
  ,
  __doc__ = """Remarketing setting for a customer.
  
  
  Attributes:
      google_global_site_tag:
          The Google global site tag.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.RemarketingSetting)
  ))
_sym_db.RegisterMessage(RemarketingSetting)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/keyword_plan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import dates_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_dates__pb2
from google.ads.google_ads.v1.proto.enums import keyword_plan_forecast_interval_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/keyword_plan.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\020KeywordPlanProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v1/proto/resources/keyword_plan.proto\x12!google.ads.googleads.v1.resources\x1a\x30google/ads/googleads_v1/proto/common/dates.proto\x1aHgoogle/ads/googleads_v1/proto/enums/keyword_plan_forecast_interval.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd0\x01\n\x0bKeywordPlan\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12U\n\x0f\x66orecast_period\x18\x04 \x01(\x0b\x32<.google.ads.googleads.v1.resources.KeywordPlanForecastPeriod\"\xdd\x01\n\x19KeywordPlanForecastPeriod\x12s\n\rdate_interval\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v1.enums.KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalH\x00\x12?\n\ndate_range\x18\x02 \x01(\x0b\x32).google.ads.googleads.v1.common.DateRangeH\x00\x42\n\n\x08intervalB\xfd\x01\n%com.google.ads.googleads.v1.resourcesB\x10KeywordPlanProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_dates__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLAN = _descriptor.Descriptor(
  name='KeywordPlan',
  full_name='google.ads.googleads.v1.resources.KeywordPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.KeywordPlan.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.KeywordPlan.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.KeywordPlan.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forecast_period', full_name='google.ads.googleads.v1.resources.KeywordPlan.forecast_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=492,
)


_KEYWORDPLANFORECASTPERIOD = _descriptor.Descriptor(
  name='KeywordPlanForecastPeriod',
  full_name='google.ads.googleads.v1.resources.KeywordPlanForecastPeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_interval', full_name='google.ads.googleads.v1.resources.KeywordPlanForecastPeriod.date_interval', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_range', full_name='google.ads.googleads.v1.resources.KeywordPlanForecastPeriod.date_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='interval', full_name='google.ads.googleads.v1.resources.KeywordPlanForecastPeriod.interval',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=495,
  serialized_end=716,
)

_KEYWORDPLAN.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLAN.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLAN.fields_by_name['forecast_period'].message_type = _KEYWORDPLANFORECASTPERIOD
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2._KEYWORDPLANFORECASTINTERVALENUM_KEYWORDPLANFORECASTINTERVAL
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_dates__pb2._DATERANGE
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
DESCRIPTOR.message_types_by_name['KeywordPlan'] = _KEYWORDPLAN
DESCRIPTOR.message_types_by_name['KeywordPlanForecastPeriod'] = _KEYWORDPLANFORECASTPERIOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlan = _reflection.GeneratedProtocolMessageType('KeywordPlan', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLAN,
  __module__ = 'google.ads.googleads_v1.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """A Keyword Planner plan. Max number of saved keyword plans: 10000. It's
  possible to remove plans if limit is reached.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Planner plan. KeywordPlan
          resource names have the form:
          ``customers/{customer_id}/keywordPlans/{kp_plan_id}``
      id:
          The ID of the keyword plan.
      name:
          The name of the keyword plan.  This field is required and
          should not be empty when creating new keyword plans.
      forecast_period:
          The date period used for forecasting the plan.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.KeywordPlan)
  ))
_sym_db.RegisterMessage(KeywordPlan)

KeywordPlanForecastPeriod = _reflection.GeneratedProtocolMessageType('KeywordPlanForecastPeriod', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANFORECASTPERIOD,
  __module__ = 'google.ads.googleads_v1.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """The forecasting period associated with the keyword plan.
  
  
  Attributes:
      interval:
          Required. The date used for forecasting the Plan.
      date_interval:
          A future date range relative to the current date used for
          forecasting.
      date_range:
          The custom date range used for forecasting. The start and end
          dates must be in the future. Otherwise, an error will be
          returned when the forecasting action is performed.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.KeywordPlanForecastPeriod)
  ))
_sym_db.RegisterMessage(KeywordPlanForecastPeriod)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import keyword_plan_negative_keyword_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_negative_keyword_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2


class KeywordPlanNegativeKeywordServiceStub(object):
  """Proto file describing the keyword plan negative keyword service.

  Service to manage Keyword Plan negative keywords.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlanNegativeKeyword = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanNegativeKeywordService/GetKeywordPlanNegativeKeyword',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.GetKeywordPlanNegativeKeywordRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2.KeywordPlanNegativeKeyword.FromString,
        )
    self.MutateKeywordPlanNegativeKeywords = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanNegativeKeywordService/MutateKeywordPlanNegativeKeywords',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.MutateKeywordPlanNegativeKeywordsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.MutateKeywordPlanNegativeKeywordsResponse.FromString,
        )


class KeywordPlanNegativeKeywordServiceServicer(object):
  """Proto file describing the keyword plan negative keyword service.

  Service to manage Keyword Plan negative keywords.
  """

  def GetKeywordPlanNegativeKeyword(self, request, context):
    """Returns the requested plan in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlanNegativeKeywords(self, request, context):
    """Creates, updates, or removes Keyword Plan negative keywords. Operation
    statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanNegativeKeywordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlanNegativeKeyword': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlanNegativeKeyword,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.GetKeywordPlanNegativeKeywordRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2.KeywordPlanNegativeKeyword.SerializeToString,
      ),
      'MutateKeywordPlanNegativeKeywords': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlanNegativeKeywords,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.MutateKeywordPlanNegativeKeywordsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__negative__keyword__service__pb2.MutateKeywordPlanNegativeKeywordsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.KeywordPlanNegativeKeywordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import conversion_action_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2
from google.ads.google_ads.v2.proto.services import conversion_action_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2


class ConversionActionServiceStub(object):
  """Proto file describing the Conversion Action service.

  Service to manage conversion actions.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetConversionAction = channel.unary_unary(
        '/google.ads.googleads.v2.services.ConversionActionService/GetConversionAction',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.GetConversionActionRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2.ConversionAction.FromString,
        )
    self.MutateConversionActions = channel.unary_unary(
        '/google.ads.googleads.v2.services.ConversionActionService/MutateConversionActions',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.MutateConversionActionsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.MutateConversionActionsResponse.FromString,
        )


class ConversionActionServiceServicer(object):
  """Proto file describing the Conversion Action service.

  Service to manage conversion actions.
  """

  def GetConversionAction(self, request, context):
    """Returns the requested conversion action.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateConversionActions(self, request, context):
    """Creates, updates or removes conversion actions. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConversionActionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetConversionAction': grpc.unary_unary_rpc_method_handler(
          servicer.GetConversionAction,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.GetConversionActionRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2.ConversionAction.SerializeToString,
      ),
      'MutateConversionActions': grpc.unary_unary_rpc_method_handler(
          servicer.MutateConversionActions,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.MutateConversionActionsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.MutateConversionActionsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ConversionActionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/keyword_plan_campaign_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import keyword_plan_campaign_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/keyword_plan_campaign_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\037KeywordPlanCampaignServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nJgoogle/ads/googleads_v1/proto/services/keyword_plan_campaign_service.proto\x12 google.ads.googleads.v1.services\x1a\x43google/ads/googleads_v1/proto/resources/keyword_plan_campaign.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"6\n\x1dGetKeywordPlanCampaignRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xbc\x01\n!MutateKeywordPlanCampaignsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v1.services.KeywordPlanCampaignOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\x82\x02\n\x1cKeywordPlanCampaignOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12H\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x36.google.ads.googleads.v1.resources.KeywordPlanCampaignH\x00\x12H\n\x06update\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v1.resources.KeywordPlanCampaignH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\xab\x01\n\"MutateKeywordPlanCampaignsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12R\n\x07results\x18\x02 \x03(\x0b\x32\x41.google.ads.googleads.v1.services.MutateKeywordPlanCampaignResult\"8\n\x1fMutateKeywordPlanCampaignResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xe0\x03\n\x1aKeywordPlanCampaignService\x12\xd1\x01\n\x16GetKeywordPlanCampaign\x12?.google.ads.googleads.v1.services.GetKeywordPlanCampaignRequest\x1a\x36.google.ads.googleads.v1.resources.KeywordPlanCampaign\">\x82\xd3\xe4\x93\x02\x38\x12\x36/v1/{resource_name=customers/*/keywordPlanCampaigns/*}\x12\xed\x01\n\x1aMutateKeywordPlanCampaigns\x12\x43.google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest\x1a\x44.google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse\"D\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id=*}/keywordPlanCampaigns:mutate:\x01*B\x86\x02\n$com.google.ads.googleads.v1.servicesB\x1fKeywordPlanCampaignServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETKEYWORDPLANCAMPAIGNREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanCampaignRequest',
  full_name='google.ads.googleads.v1.services.GetKeywordPlanCampaignRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetKeywordPlanCampaignRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=356,
)


_MUTATEKEYWORDPLANCAMPAIGNSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignsRequest',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=547,
)


_KEYWORDPLANCAMPAIGNOPERATION = _descriptor.Descriptor(
  name='KeywordPlanCampaignOperation',
  full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=550,
  serialized_end=808,
)


_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignsResponse',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=982,
)


_MUTATEKEYWORDPLANCAMPAIGNRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignResult',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateKeywordPlanCampaignResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1040,
)

_MUTATEKEYWORDPLANCAMPAIGNSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANCAMPAIGNOPERATION
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['remove'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANCAMPAIGNRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanCampaignRequest'] = _GETKEYWORDPLANCAMPAIGNREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignsRequest'] = _MUTATEKEYWORDPLANCAMPAIGNSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanCampaignOperation'] = _KEYWORDPLANCAMPAIGNOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignsResponse'] = _MUTATEKEYWORDPLANCAMPAIGNSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignResult'] = _MUTATEKEYWORDPLANCAMPAIGNRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanCampaignRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanCampaignRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANCAMPAIGNREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanCampaignService.GetKeywordPlanCampaign][google.ads.googleads.v1.services.KeywordPlanCampaignService.GetKeywordPlanCampaign].
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan campaign to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetKeywordPlanCampaignRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanCampaignRequest)

MutateKeywordPlanCampaignsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanCampaignService.MutateKeywordPlanCampaigns][google.ads.googleads.v1.services.KeywordPlanCampaignService.MutateKeywordPlanCampaigns].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose Keyword Plan campaigns are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          campaigns.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignsRequest)

KeywordPlanCampaignOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanCampaignOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANCAMPAIGNOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan campaign.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan campaign.
      update:
          Update operation: The Keyword Plan campaign is expected to
          have a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          campaign is expected, in this format:  ``customers/{customer_i
          d}/keywordPlanCampaigns/{keywordPlan_campaign_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanCampaignOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanCampaignOperation)

MutateKeywordPlanCampaignsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan campaign mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignsResponse)

MutateKeywordPlanCampaignResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan campaign mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlanCampaignResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignResult)


DESCRIPTOR._options = None

_KEYWORDPLANCAMPAIGNSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanCampaignService',
  full_name='google.ads.googleads.v1.services.KeywordPlanCampaignService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1043,
  serialized_end=1523,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanCampaign',
    full_name='google.ads.googleads.v1.services.KeywordPlanCampaignService.GetKeywordPlanCampaign',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANCAMPAIGNREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN,
    serialized_options=_b('\202\323\344\223\0028\0226/v1/{resource_name=customers/*/keywordPlanCampaigns/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanCampaigns',
    full_name='google.ads.googleads.v1.services.KeywordPlanCampaignService.MutateKeywordPlanCampaigns',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANCAMPAIGNSREQUEST,
    output_type=_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE,
    serialized_options=_b('\202\323\344\223\002>\"9/v1/customers/{customer_id=*}/keywordPlanCampaigns:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANCAMPAIGNSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanCampaignService'] = _KEYWORDPLANCAMPAIGNSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_criterion_simulation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import simulation_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_simulation__pb2
from google.ads.google_ads.v1.proto.enums import simulation_modification_method_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__modification__method__pb2
from google.ads.google_ads.v1.proto.enums import simulation_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_criterion_simulation.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB CampaignCriterionSimulationProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nKgoogle/ads/googleads_v1/proto/resources/campaign_criterion_simulation.proto\x12!google.ads.googleads.v1.resources\x1a\x35google/ads/googleads_v1/proto/common/simulation.proto\x1aHgoogle/ads/googleads_v1/proto/enums/simulation_modification_method.proto\x1a\x39google/ads/googleads_v1/proto/enums/simulation_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb7\x04\n\x1b\x43\x61mpaignCriterionSimulation\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x30\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0c\x63riterion_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12N\n\x04type\x18\x04 \x01(\x0e\x32@.google.ads.googleads.v1.enums.SimulationTypeEnum.SimulationType\x12y\n\x13modification_method\x18\x05 \x01(\x0e\x32\\.google.ads.googleads.v1.enums.SimulationModificationMethodEnum.SimulationModificationMethod\x12\x30\n\nstart_date\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x61\n\x17\x62id_modifier_point_list\x18\x08 \x01(\x0b\x32>.google.ads.googleads.v1.common.BidModifierSimulationPointListH\x00\x42\x0c\n\npoint_listB\x8d\x02\n%com.google.ads.googleads.v1.resourcesB CampaignCriterionSimulationProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_simulation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__modification__method__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNCRITERIONSIMULATION = _descriptor.Descriptor(
  name='CampaignCriterionSimulation',
  full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_id', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.campaign_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.criterion_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modification_method', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.modification_method', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.start_date', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.end_date', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier_point_list', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.bid_modifier_point_list', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='point_list', full_name='google.ads.googleads.v1.resources.CampaignCriterionSimulation.point_list',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=365,
  serialized_end=932,
)

_CAMPAIGNCRITERIONSIMULATION.fields_by_name['campaign_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__type__pb2._SIMULATIONTYPEENUM_SIMULATIONTYPE
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['modification_method'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_simulation__modification__method__pb2._SIMULATIONMODIFICATIONMETHODENUM_SIMULATIONMODIFICATIONMETHOD
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['bid_modifier_point_list'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_simulation__pb2._BIDMODIFIERSIMULATIONPOINTLIST
_CAMPAIGNCRITERIONSIMULATION.oneofs_by_name['point_list'].fields.append(
  _CAMPAIGNCRITERIONSIMULATION.fields_by_name['bid_modifier_point_list'])
_CAMPAIGNCRITERIONSIMULATION.fields_by_name['bid_modifier_point_list'].containing_oneof = _CAMPAIGNCRITERIONSIMULATION.oneofs_by_name['point_list']
DESCRIPTOR.message_types_by_name['CampaignCriterionSimulation'] = _CAMPAIGNCRITERIONSIMULATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignCriterionSimulation = _reflection.GeneratedProtocolMessageType('CampaignCriterionSimulation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNCRITERIONSIMULATION,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_criterion_simulation_pb2'
  ,
  __doc__ = """A campaign criterion simulation. Supported combinations of advertising
  channel type, criterion ids, simulation type and simulation modification
  method is detailed below respectively.
  
  SEARCH 30000,30001,30002 BID\_MODIFIER UNIFORM DISPLAY 30001
  BID\_MODIFIER UNIFORM
  
  
  Attributes:
      resource_name:
          The resource name of the campaign criterion simulation.
          Campaign criterion simulation resource names have the form:  `
          `customers/{customer_id}/campaignCriterionSimulations/{campaig
          n_id}~{criterion_id}~{type}~{modification_method}~{start_date}
          ~{end_date}``
      campaign_id:
          Campaign ID of the simulation.
      criterion_id:
          Criterion ID of the simulation.
      type:
          The field that the simulation modifies.
      modification_method:
          How the simulation modifies the field.
      start_date:
          First day on which the simulation is based, in YYYY-MM-DD
          format.
      end_date:
          Last day on which the simulation is based, in YYYY-MM-DD
          format.
      point_list:
          List of simulation points.
      bid_modifier_point_list:
          Simulation points if the simulation type is BID\_MODIFIER.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignCriterionSimulation)
  ))
_sym_db.RegisterMessage(CampaignCriterionSimulation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/ad_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/ad_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\014AdErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n3google/ads/googleads_v1/proto/errors/ad_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xf0 \n\x0b\x41\x64\x45rrorEnum\"\xe0 \n\x07\x41\x64\x45rror\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12,\n(AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE\x10\x02\x12\x1a\n\x16\x41PPROXIMATELY_TOO_LONG\x10\x03\x12\x1b\n\x17\x41PPROXIMATELY_TOO_SHORT\x10\x04\x12\x0f\n\x0b\x42\x41\x44_SNIPPET\x10\x05\x12\x14\n\x10\x43\x41NNOT_MODIFY_AD\x10\x06\x12\'\n#CANNOT_SET_BUSINESS_NAME_IF_URL_SET\x10\x07\x12\x14\n\x10\x43\x41NNOT_SET_FIELD\x10\x08\x12*\n&CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET\x10\t\x12/\n+CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING\x10\n\x12)\n%CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE\x10\x0b\x12\x37\n3CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING\x10\x0c\x12\x12\n\x0e\x43\x41NNOT_SET_URL\x10\r\x12!\n\x1d\x43\x41NNOT_SET_WITHOUT_FINAL_URLS\x10\x0e\x12\x1e\n\x1a\x43\x41NNOT_SET_WITH_FINAL_URLS\x10\x0f\x12\x1c\n\x18\x43\x41NNOT_SET_WITH_URL_DATA\x10\x11\x12\'\n#CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR\x10\x12\x12#\n\x1f\x43USTOMER_NOT_APPROVED_MOBILEADS\x10\x13\x12(\n$CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS\x10\x14\x12\x31\n-CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS\x10\x15\x12\x19\n\x15\x43USTOMER_NOT_ELIGIBLE\x10\x16\x12\x31\n-CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL\x10\x17\x12\x1e\n\x1a\x44IMENSION_ALREADY_IN_UNION\x10\x18\x12\x19\n\x15\x44IMENSION_MUST_BE_SET\x10\x19\x12\x1a\n\x16\x44IMENSION_NOT_IN_UNION\x10\x1a\x12#\n\x1f\x44ISPLAY_URL_CANNOT_BE_SPECIFIED\x10\x1b\x12 \n\x1c\x44OMESTIC_PHONE_NUMBER_FORMAT\x10\x1c\x12\x1a\n\x16\x45MERGENCY_PHONE_NUMBER\x10\x1d\x12\x0f\n\x0b\x45MPTY_FIELD\x10\x1e\x12\x30\n,FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID\x10\x1f\x12(\n$FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH\x10 \x12!\n\x1dILLEGAL_AD_CUSTOMIZER_TAG_USE\x10!\x12\x13\n\x0fILLEGAL_TAG_USE\x10\"\x12\x1b\n\x17INCONSISTENT_DIMENSIONS\x10#\x12)\n%INCONSISTENT_STATUS_IN_TEMPLATE_UNION\x10$\x12\x14\n\x10INCORRECT_LENGTH\x10%\x12\x1a\n\x16INELIGIBLE_FOR_UPGRADE\x10&\x12&\n\"INVALID_AD_ADDRESS_CAMPAIGN_TARGET\x10\'\x12\x13\n\x0fINVALID_AD_TYPE\x10(\x12\'\n#INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE\x10)\x12&\n\"INVALID_ATTRIBUTES_FOR_MOBILE_TEXT\x10*\x12\x1f\n\x1bINVALID_CALL_TO_ACTION_TEXT\x10+\x12\x1d\n\x19INVALID_CHARACTER_FOR_URL\x10,\x12\x18\n\x14INVALID_COUNTRY_CODE\x10-\x12*\n&INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG\x10/\x12\x11\n\rINVALID_INPUT\x10\x30\x12\x1b\n\x17INVALID_MARKUP_LANGUAGE\x10\x31\x12\x1a\n\x16INVALID_MOBILE_CARRIER\x10\x32\x12!\n\x1dINVALID_MOBILE_CARRIER_TARGET\x10\x33\x12\x1e\n\x1aINVALID_NUMBER_OF_ELEMENTS\x10\x34\x12\x1f\n\x1bINVALID_PHONE_NUMBER_FORMAT\x10\x35\x12\x31\n-INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID\x10\x36\x12\x19\n\x15INVALID_TEMPLATE_DATA\x10\x37\x12\'\n#INVALID_TEMPLATE_ELEMENT_FIELD_TYPE\x10\x38\x12\x17\n\x13INVALID_TEMPLATE_ID\x10\x39\x12\x11\n\rLINE_TOO_WIDE\x10:\x12!\n\x1dMISSING_AD_CUSTOMIZER_MAPPING\x10;\x12\x1d\n\x19MISSING_ADDRESS_COMPONENT\x10<\x12\x1e\n\x1aMISSING_ADVERTISEMENT_NAME\x10=\x12\x19\n\x15MISSING_BUSINESS_NAME\x10>\x12\x18\n\x14MISSING_DESCRIPTION1\x10?\x12\x18\n\x14MISSING_DESCRIPTION2\x10@\x12\x1f\n\x1bMISSING_DESTINATION_URL_TAG\x10\x41\x12 \n\x1cMISSING_LANDING_PAGE_URL_TAG\x10\x42\x12\x15\n\x11MISSING_DIMENSION\x10\x43\x12\x17\n\x13MISSING_DISPLAY_URL\x10\x44\x12\x14\n\x10MISSING_HEADLINE\x10\x45\x12\x12\n\x0eMISSING_HEIGHT\x10\x46\x12\x11\n\rMISSING_IMAGE\x10G\x12-\n)MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS\x10H\x12\x1c\n\x18MISSING_MARKUP_LANGUAGES\x10I\x12\x1a\n\x16MISSING_MOBILE_CARRIER\x10J\x12\x11\n\rMISSING_PHONE\x10K\x12$\n MISSING_REQUIRED_TEMPLATE_FIELDS\x10L\x12 \n\x1cMISSING_TEMPLATE_FIELD_VALUE\x10M\x12\x10\n\x0cMISSING_TEXT\x10N\x12\x17\n\x13MISSING_VISIBLE_URL\x10O\x12\x11\n\rMISSING_WIDTH\x10P\x12\'\n#MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED\x10Q\x12$\n MUST_USE_TEMP_AD_UNION_ID_ON_ADD\x10R\x12\x0c\n\x08TOO_LONG\x10S\x12\r\n\tTOO_SHORT\x10T\x12\"\n\x1eUNION_DIMENSIONS_CANNOT_CHANGE\x10U\x12\x1d\n\x19UNKNOWN_ADDRESS_COMPONENT\x10V\x12\x16\n\x12UNKNOWN_FIELD_NAME\x10W\x12\x17\n\x13UNKNOWN_UNIQUE_NAME\x10X\x12\x1a\n\x16UNSUPPORTED_DIMENSIONS\x10Y\x12\x16\n\x12URL_INVALID_SCHEME\x10Z\x12 \n\x1cURL_INVALID_TOP_LEVEL_DOMAIN\x10[\x12\x11\n\rURL_MALFORMED\x10\\\x12\x0f\n\x0bURL_NO_HOST\x10]\x12\x16\n\x12URL_NOT_EQUIVALENT\x10^\x12\x1a\n\x16URL_HOST_NAME_TOO_LONG\x10_\x12\x11\n\rURL_NO_SCHEME\x10`\x12\x1b\n\x17URL_NO_TOP_LEVEL_DOMAIN\x10\x61\x12\x18\n\x14URL_PATH_NOT_ALLOWED\x10\x62\x12\x18\n\x14URL_PORT_NOT_ALLOWED\x10\x63\x12\x19\n\x15URL_QUERY_NOT_ALLOWED\x10\x64\x12\x34\n0URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG\x10\x66\x12)\n%USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE\x10g\x12$\n INCONSISTENT_EXPANDABLE_SETTINGS\x10h\x12\x12\n\x0eINVALID_FORMAT\x10i\x12\x16\n\x12INVALID_FIELD_TEXT\x10j\x12\x17\n\x13\x45LEMENT_NOT_PRESENT\x10k\x12\x0f\n\x0bIMAGE_ERROR\x10l\x12\x16\n\x12VALUE_NOT_IN_RANGE\x10m\x12\x15\n\x11\x46IELD_NOT_PRESENT\x10n\x12\x18\n\x14\x41\x44\x44RESS_NOT_COMPLETE\x10o\x12\x13\n\x0f\x41\x44\x44RESS_INVALID\x10p\x12\x19\n\x15VIDEO_RETRIEVAL_ERROR\x10q\x12\x0f\n\x0b\x41UDIO_ERROR\x10r\x12\x1f\n\x1bINVALID_YOUTUBE_DISPLAY_URL\x10s\x12\x1b\n\x17TOO_MANY_PRODUCT_IMAGES\x10t\x12\x1b\n\x17TOO_MANY_PRODUCT_VIDEOS\x10u\x12.\n*INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE\x10v\x12*\n&CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY\x10w\x12-\n)CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED\x10x\x12\x1a\n\x16\x44ISALLOWED_NUMBER_TYPE\x10y\x12*\n&PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY\x10z\x12<\n8PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY\x10{\x12#\n\x1fPREMIUM_RATE_NUMBER_NOT_ALLOWED\x10|\x12#\n\x1fVANITY_PHONE_NUMBER_NOT_ALLOWED\x10}\x12#\n\x1fINVALID_CALL_CONVERSION_TYPE_ID\x10~\x12=\n9CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID\x10\x7f\x12#\n\x1e\x43\x41NNOT_SET_PATH2_WITHOUT_PATH1\x10\x80\x01\x12\x33\n.MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME\x10\x81\x01\x12\'\n\"INCOMPATIBLE_WITH_RESTRICTION_TYPE\x10\x82\x01\x12\x31\n,CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED\x10\x83\x01\x12\"\n\x1dMISSING_IMAGE_OR_MEDIA_BUNDLE\x10\x84\x01\x12\x30\n+PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN\x10\x85\x01\x42\xe7\x01\n\"com.google.ads.googleads.v1.errorsB\x0c\x41\x64\x45rrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_ADERRORENUM_ADERROR = _descriptor.EnumDescriptor(
  name='AdError',
  full_name='google.ads.googleads.v1.errors.AdErrorEnum.AdError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPROXIMATELY_TOO_LONG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPROXIMATELY_TOO_SHORT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_SNIPPET', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_AD', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_BUSINESS_NAME_IF_URL_SET', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_FIELD', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_URL', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_WITHOUT_FINAL_URLS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_WITH_FINAL_URLS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_WITH_URL_DATA', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_APPROVED_MOBILEADS', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_ELIGIBLE', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL', index=22, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIMENSION_ALREADY_IN_UNION', index=23, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIMENSION_MUST_BE_SET', index=24, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIMENSION_NOT_IN_UNION', index=25, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_URL_CANNOT_BE_SPECIFIED', index=26, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOMESTIC_PHONE_NUMBER_FORMAT', index=27, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PHONE_NUMBER', index=28, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPTY_FIELD', index=29, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_AD_CUSTOMIZER_TAG_USE', index=32, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_TAG_USE', index=33, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCONSISTENT_DIMENSIONS', index=34, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCONSISTENT_STATUS_IN_TEMPLATE_UNION', index=35, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_LENGTH', index=36, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INELIGIBLE_FOR_UPGRADE', index=37, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_AD_ADDRESS_CAMPAIGN_TARGET', index=38, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_AD_TYPE', index=39, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE', index=40, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ATTRIBUTES_FOR_MOBILE_TEXT', index=41, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CALL_TO_ACTION_TEXT', index=42, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CHARACTER_FOR_URL', index=43, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_COUNTRY_CODE', index=44, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG', index=45, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_INPUT', index=46, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MARKUP_LANGUAGE', index=47, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MOBILE_CARRIER', index=48, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MOBILE_CARRIER_TARGET', index=49, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NUMBER_OF_ELEMENTS', index=50, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PHONE_NUMBER_FORMAT', index=51, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID', index=52, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TEMPLATE_DATA', index=53, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TEMPLATE_ELEMENT_FIELD_TYPE', index=54, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TEMPLATE_ID', index=55, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINE_TOO_WIDE', index=56, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_AD_CUSTOMIZER_MAPPING', index=57, number=59,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_ADDRESS_COMPONENT', index=58, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_ADVERTISEMENT_NAME', index=59, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_BUSINESS_NAME', index=60, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DESCRIPTION1', index=61, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DESCRIPTION2', index=62, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DESTINATION_URL_TAG', index=63, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_LANDING_PAGE_URL_TAG', index=64, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DIMENSION', index=65, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DISPLAY_URL', index=66, number=68,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HEADLINE', index=67, number=69,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HEIGHT', index=68, number=70,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_IMAGE', index=69, number=71,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS', index=70, number=72,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_MARKUP_LANGUAGES', index=71, number=73,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_MOBILE_CARRIER', index=72, number=74,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PHONE', index=73, number=75,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_REQUIRED_TEMPLATE_FIELDS', index=74, number=76,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_TEMPLATE_FIELD_VALUE', index=75, number=77,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_TEXT', index=76, number=78,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_VISIBLE_URL', index=77, number=79,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_WIDTH', index=78, number=80,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED', index=79, number=81,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUST_USE_TEMP_AD_UNION_ID_ON_ADD', index=80, number=82,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_LONG', index=81, number=83,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_SHORT', index=82, number=84,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNION_DIMENSIONS_CANNOT_CHANGE', index=83, number=85,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ADDRESS_COMPONENT', index=84, number=86,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FIELD_NAME', index=85, number=87,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNIQUE_NAME', index=86, number=88,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_DIMENSIONS', index=87, number=89,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_INVALID_SCHEME', index=88, number=90,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_INVALID_TOP_LEVEL_DOMAIN', index=89, number=91,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_MALFORMED', index=90, number=92,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_NO_HOST', index=91, number=93,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_NOT_EQUIVALENT', index=92, number=94,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_HOST_NAME_TOO_LONG', index=93, number=95,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_NO_SCHEME', index=94, number=96,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_NO_TOP_LEVEL_DOMAIN', index=95, number=97,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_PATH_NOT_ALLOWED', index=96, number=98,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_PORT_NOT_ALLOWED', index=97, number=99,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_QUERY_NOT_ALLOWED', index=98, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG', index=99, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE', index=100, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCONSISTENT_EXPANDABLE_SETTINGS', index=101, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FORMAT', index=102, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FIELD_TEXT', index=103, number=106,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ELEMENT_NOT_PRESENT', index=104, number=107,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_ERROR', index=105, number=108,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_NOT_IN_RANGE', index=106, number=109,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIELD_NOT_PRESENT', index=107, number=110,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS_NOT_COMPLETE', index=108, number=111,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS_INVALID', index=109, number=112,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_RETRIEVAL_ERROR', index=110, number=113,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO_ERROR', index=111, number=114,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_YOUTUBE_DISPLAY_URL', index=112, number=115,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_PRODUCT_IMAGES', index=113, number=116,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_PRODUCT_VIDEOS', index=114, number=117,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE', index=115, number=118,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY', index=116, number=119,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED', index=117, number=120,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISALLOWED_NUMBER_TYPE', index=118, number=121,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY', index=119, number=122,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY', index=120, number=123,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM_RATE_NUMBER_NOT_ALLOWED', index=121, number=124,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VANITY_PHONE_NUMBER_NOT_ALLOWED', index=122, number=125,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CALL_CONVERSION_TYPE_ID', index=123, number=126,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID', index=124, number=127,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_PATH2_WITHOUT_PATH1', index=125, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME', index=126, number=129,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMPATIBLE_WITH_RESTRICTION_TYPE', index=127, number=130,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED', index=128, number=131,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_IMAGE_OR_MEDIA_BUNDLE', index=129, number=132,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN', index=130, number=133,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=134,
  serialized_end=4326,
)
_sym_db.RegisterEnumDescriptor(_ADERRORENUM_ADERROR)


_ADERRORENUM = _descriptor.Descriptor(
  name='AdErrorEnum',
  full_name='google.ads.googleads.v1.errors.AdErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADERRORENUM_ADERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=4326,
)

_ADERRORENUM_ADERROR.containing_type = _ADERRORENUM
DESCRIPTOR.message_types_by_name['AdErrorEnum'] = _ADERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdErrorEnum = _reflection.GeneratedProtocolMessageType('AdErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.ad_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ad errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.AdErrorEnum)
  ))
_sym_db.RegisterMessage(AdErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
